@@ -7,6 +7,7 @@ use App::Ack ();
 use App::Ack::ConfigDefault ();
 use App::Ack::ConfigFinder ();
 use App::Ack::Filter;
+use App::Ack::Filter::Collection;
 use App::Ack::Filter::Default;
 use Carp 1.04 ();
 use Getopt::Long 2.38 ();
@@ -442,7 +443,8 @@ sub process_other {
                 die "Options --output, --pager and --match are forbidden in project .ackrc files.\n";
             };
 
-            $args_for_source = { %$args_for_source,
+            $args_for_source = {
+                %{$args_for_source},
                 'output=s' => $illegal,
                 'pager:s'  => $illegal,
                 'match=s'  => $illegal,
